/**
 * Set the seed for our prng and switch to a simple, seedable prng
 *
 * ```typescript
 * import { randomInt, setSeed } from 'goodish'
 * setSeed(11)
 * randomInt(1, 100) // always 44
 * ```
 *
 * @param seed
 */
export declare function setSeed(seed: number): void;
/**
 * Remove any previously set seed on the random number generator
 *
 * ```typescript
 * import { clearSeed } from 'goodish'
 * clearSeed() // Now randomized functions will use Math.random again
 * ```
 */
export declare function clearSeed(): void;
/**
 * Returns a random float between min and max.
 *
 * ```typescript
 * import { random } from 'goodish'
 * console.log(random()) // value between 0 and 1
 * console.log(random(0, 100) // value between 0 and 100
 *
 * @param min
 * @param max
 */
export declare function random(min?: number, max?: number): number;
/**
 * Returns a random integer between the min and max values.
 *
 * ```typescript
 * import { randomInt } from 'goodish'
 * console.log(randomInt(0, 100)) // Some integer between 0 and 100
 * ```
 *
 * @param min
 * @param max
 */
export declare function randomInt(min: number, max: number): number;
/**
 * Round a number to the specified number of digits
 *
 * ```typescript
 * import { toFixedNum } from 'goodish'
 * console.log(toFixedNum(3.14159, 2)) // 3.14
 * ```
 *
 * @param float
 * @param digits
 */
export declare function toFixedNum(float: number, digits: number): number;
/**
 * Calculate the greatest common divisor of two numbers
 *
 * ```typescript
 * import { greatestCommonDivisor } from 'goodish'
 * console.log(greatestCommonDivisor(18, 12)) // 6
 * ```
 *
 * @param numA
 * @param numB
 * @reference Adapted from [this site](https://www.w3resource.com/javascript-exercises/javascript-math-exercise-8.php)
 */
export declare function greatestCommonDivisor(numA: number, numB: number): number;
/**
 * Calculate the lowest common multiple of two numbers
 *
 * ```typescript
 * import { lowestCommonMultiple } from 'goodish'
 * console.log(lowestCommonMultiple(6, 8)) // 24
 * ```
 *
 * @param numA
 * @param numB
 * @reference Adapted from [this site](https://www.w3resource.com/javascript-exercises/javascript-math-exercise-10.php)
 */
export declare function lowestCommonMultiple(numA: number, numB: number): number;
/**
 * Clamp a value between the min and max values. If it is below min or above max then we set the value equal to the
 * respective boundary.
 *
 * ```typescript
 * import { clamp } from 'goodish'
 * console.log(clamp(100, 0, 10)) // 10
 * ```
 *
 * @param val
 * @param min
 * @param max
 */
export declare function clamp(val: number, min: number, max: number): number;
/**
 * Wrap the value within these bounds. More explanation of the idea (here)[https://en.wikipedia.org/wiki/Wrapping_(graphics)]
 *
 * ```typescript
 * import { wrap } from 'goodish'
 * console.log(wrap(5, 1, 4)) // 2 because value exceeds the max val by 1 and wraps around from the lower boundary
 * ```
 *
 * @param val
 * @param min
 * @param max
 */
export declare function wrap(val: number, min: number, max: number): number;
