"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class Vector2D {
    constructor(x, y) {
        this.x = x;
        this.y = y;
    }
    add(v) {
        this.x += v.x;
        this.y += v.y;
        return this;
    }
    subtract(v) {
        this.x -= v.x;
        this.y -= v.y;
        return this;
    }
    subtractC(v) {
        return new Vector2D(this.x - v.x, this.y - v.y);
    }
    addC(v) {
        return new Vector2D(this.x + v.x, this.y + v.y);
    }
    magSqrd() {
        return Math.pow(this.x, 2) + Math.pow(this.y, 2);
    }
    mag() {
        return Math.sqrt(this.magSqrd());
    }
    dot(v) {
        return this.x * v.x + this.y * v.y;
    }
    normalize(mag = 1) {
        const oldMag = this.mag();
        if (oldMag !== 0) {
            this.x = mag * this.x / oldMag;
            this.y = mag * this.y / oldMag;
        }
        return this;
    }
    normalizeC(mag = 1) {
        const oldMag = this.mag();
        const x = oldMag !== 0 ? mag * this.x / oldMag : this.x;
        const y = oldMag !== 0 ? mag * this.y / oldMag : this.y;
        return new Vector2D(x, y);
    }
    zero() {
        this.x = 0;
        this.y = 0;
        return this;
    }
    rotate(angle) {
        const x = this.x;
        this.x = x * Math.cos(angle) - this.y * Math.sin(angle);
        this.y = x * Math.sin(angle) + this.y * Math.cos(angle);
        return this;
    }
    angle() {
        return Math.atan2(this.y, this.x);
    }
    perpendicular() {
        return new Vector2D(this.x, -this.y);
    }
    angleBetween(v) {
        return Math.atan2(this.y - v.y, this.x - v.x);
    }
    copy() {
        return new Vector2D(this.x, this.y);
    }
    static midPoint(a, b) {
        return new Vector2D((a.x + b.x) / 2, (a.y + b.y) / 2);
    }
    static fromPoints(a, b) {
        return new Vector2D(a.x - b.x, a.y - b.y);
    }
    static fromPoint(a) {
        return new Vector2D(a.x, a.y);
    }
}
exports.Vector2D = Vector2D;
